@@ -237,7 +237,8 @@ def switch_to_branch(repo, branch_name):
 # TITLE: infer from JIRA issue title
 # DESCRIPTION: default is link to JIRA issue, user can then edit once MR has been created
 
-def create_merge_request(target: Path, source_branch: str, target_branch: str, issue_id: str, title: str):
+def create_merge_request(target: Path, source_branch: str, target_branch: str, issue_id: str, issue_url: str,
+                         title: str):
     spinner = Halo(text=f'Creating MR for {issue_id}', spinner='dots')
     spinner.start()
 
@@ -274,14 +275,49 @@ def create_merge_request(target: Path, source_branch: str, target_branch: str, i
         click.secho(f'One or more pending MR already exist for this issue... aborting', fg='red')
         exit(1)
 
+    # check if upstream branch is set
+    set_upstream_branch = True
+    try:
+        upstream_branch = repo.git.execute(["git", "rev-parse", "--abbrev-ref", f"{source_branch}@{{upstream}}"])
+        if source_branch in upstream_branch:
+            set_upstream_branch = False
+    except GitCommandError:
+        click.secho(f"No upstream configured for {source_branch}", fg='blue')
+
+    if set_upstream_branch:
+        try:
+            repo.git.execute(["git", "push", "-u", "origin", source_branch])
+        except GitCommandError as err:
+            click.secho(f'Something failed while trying to push...', fg='red')
+            click.echo(err)
+            exit(1)
+    else:
+        # only create the MR if there are pending commits
+        pending_commits = repo.git.execute(["git", "log", "@{upstream}.."])
+
+        # or merges
+        pending_merges = repo.git.execute(["git", "log", f"{target_branch}.."])
+
+        if not pending_commits and not pending_merges:
+            click.secho(f'No commits to push, nothing to do here!', fg='green')
+            exit(1)
+        else:
+            try:
+                repo.git.execute(["git", "push"])
+            except GitCommandError as err:
+                click.secho(f'Something failed while trying to push...', fg='red')
+                click.echo(err)
+                exit(1)
+
     # WE ARE GOOD TO GO!
-    title = f'[WIP] {title}'  # MARK THE MR AS WORK IN PROGRESS
+    title = f'{title}'  # MARK THE MR AS WORK IN PROGRESS
+
     mr_payload = {'source_branch': source_branch,
                   'target_branch': target_branch,
                   'title': title,
                   'squash': True,
                   'remove_source_branch': True,
-                  'description': f'[{issue_id}]()'
+                  'description': f'[{issue_id}]({issue_url})'
                   }
 
     try:
@@ -376,8 +412,10 @@ def cli(issue_id_or_url, name_only, push, target: Path, merge_request):
             target_branch = create_branch(branch_name, push, target)
         except Exception:
             exit(1)
-        if target_branch and merge_request and push:
-            create_merge_request(target, branch_name, target_branch, issue_id, mr_title)
+        if target_branch and merge_request:
+            credentials = get_credentials()
+            create_merge_request(target, branch_name, target_branch, issue_id,
+                                 f'{credentials.url}/browse/{issue_id}', mr_title)
 
 
 if __name__ == '__main__':
